@@ -9,7 +9,6 @@ from OpenGL.GL import (
 from .operation_ui import OperationUI
 from amulet_map_editor.programs.edit.api.behaviour import StaticSelectionBehaviour
 from amulet_map_editor.api.opengl.camera import Projection
-from amulet_map_editor.programs.edit.api.events import EVT_DRAW
 from amulet_map_editor.programs.edit.api.behaviour import (
     CameraBehaviour,
     PointerBehaviour,
@@ -52,25 +51,29 @@ class DefaultOperationUI(OperationUI):
 
     def bind_events(self):
         self._selection.bind_events()
-        self.canvas.Bind(EVT_DRAW, self._on_draw)
+        self.canvas.Bind(wx.EVT_PAINT, self._on_draw)
         self._camera_behaviour.bind_events()
         self._pointer.bind_events()
         self.canvas.Bind(EVT_INPUT_PRESS, self._on_input_press)
 
     def _on_draw(self, evt):
         try:
-            self.canvas.renderer.start_draw()
-            if self.canvas.camera.projection_mode == Projection.PERSPECTIVE:
-                self.canvas.renderer.draw_sky_box()
-                glClear(GL_DEPTH_BUFFER_BIT)
-            self.canvas.renderer.draw_level()
-            self._selection.draw()
-            if self._show_pointer:
-                self._pointer.draw()
-            self.canvas.renderer.end_draw()
+            self.canvas.SetCurrent(self.canvas.context)
+            self._draw()
         except Exception as e:
             log.exception(f"Failed painting: {e}")
 
+    def _draw(self):
+        self.canvas.renderer.start_draw()
+        if self.canvas.camera.projection_mode == Projection.PERSPECTIVE:
+            self.canvas.renderer.draw_sky_box()
+            glClear(GL_DEPTH_BUFFER_BIT)
+        self.canvas.renderer.draw_level()
+        self._selection.draw()
+        if self._show_pointer:
+            self._pointer.draw()
+        self.canvas.renderer.end_draw()
+
     def _on_input_press(self, evt: InputPressEvent):
         if evt.action_id == ACT_BOX_CLICK:
             self._on_box_click()
