@@ -14,7 +14,6 @@ from amulet.api.errors import LoaderNoneMatched
 from amulet_map_editor.api.wx.ui.traceback_dialog import TracebackDialog
 from amulet_map_editor.api.opengl.camera import Projection
 from .base_tool_ui import BaseToolUI
-from amulet_map_editor.programs.edit.api.events import EVT_DRAW
 from amulet_map_editor.programs.edit.api.behaviour import CameraBehaviour
 
 if TYPE_CHECKING:
@@ -43,7 +42,7 @@ class DefaultBaseToolUI(BaseToolUI):
         """Bind all required events to the canvas.
         All events on the canvas will be automatically removed after the tool is disabled.
         """
-        self.canvas.Bind(EVT_DRAW, self._on_draw)
+        self.canvas.Bind(wx.EVT_PAINT, self._on_draw)
         self.canvas.SetDropTarget(None)  # fixes #239
         self.canvas.DragAcceptFiles(True)
         self.canvas.Bind(wx.EVT_DROP_FILES, self._on_drop_files)
@@ -52,15 +51,19 @@ class DefaultBaseToolUI(BaseToolUI):
     def _on_draw(self, evt):
         """The render loop for this tool."""
         try:
-            self.canvas.renderer.start_draw()
-            if self.canvas.camera.projection_mode == Projection.PERSPECTIVE:
-                self.canvas.renderer.draw_sky_box()
-                glClear(GL_DEPTH_BUFFER_BIT)
-            self.canvas.renderer.draw_level()
-            self.canvas.renderer.end_draw()
+            self.canvas.SetCurrent(self.canvas.context)
+            self._draw()
         except Exception as e:
             log.exception(f"Failed painting: {e}")
 
+    def _draw(self):
+        self.canvas.renderer.start_draw()
+        if self.canvas.camera.projection_mode == Projection.PERSPECTIVE:
+            self.canvas.renderer.draw_sky_box()
+            glClear(GL_DEPTH_BUFFER_BIT)
+        self.canvas.renderer.draw_level()
+        self.canvas.renderer.end_draw()
+
     def _on_drop_files(self, evt: wx.DropFilesEvent):
         """Logic to run when a file is dropped into the canvas."""
         paths = evt.GetFiles()
