@@ -46,9 +46,8 @@ class EditExtension(wx.Panel, BaseProgram):
     def __init__(self, parent, world: "World"):
         wx.Panel.__init__(self, parent)
         self._sizer = wx.BoxSizer(wx.VERTICAL)
-        self.SetBackgroundColour(
-            tuple(int(v * 255) for v in EditCanvas.background_colour)
-        )
+        r, g, b = (int(v * 255) for v in EditCanvas.background_colour)
+        self.SetBackgroundColour(wx.Colour(r, g, b))
         self.SetSizer(self._sizer)
         self._world = world
         self._canvas = None
@@ -135,11 +134,9 @@ class EditExtension(wx.Panel, BaseProgram):
             self._sizer.Clear(True)
             self._sizer.Add(self._canvas, 1, wx.EXPAND)
             self._canvas.Show()
-            self._canvas._set_size()
             self.Layout()
-            wx.CallAfter(
-                self._canvas.enable
-            )  # This must be called after the show handler is run
+            # This must be called after the show handler is run
+            wx.CallAfter(self._canvas.enable)
             self._setup_thread = None
         except Exception as e:
             wx.CallAfter(self._display_error, str(e), traceback.format_exc())
